@@ -19,9 +19,19 @@ async fn main() -> Result<()> {
     let manipulator = file_io::FileManipulator::new(
         args.input_dir,
         args.output_dir,
-        usize::from(args.max_backups),
+        args.max_backups,
         args.compression_level,
     );
+    if let Err(e) = manipulator
+        .truncate_target_dir()
+        .with_context(|| "Failed to truncate target directory")
+    {
+        server
+            .disconnect(false)
+            .await
+            .with_context(|| "Failed to send final RCON messages")?;
+        bail!(e);
+    }
     match manipulator.read_to_zip() {
         Ok(_) => {
             server
@@ -37,15 +47,5 @@ async fn main() -> Result<()> {
             bail!(e);
         }
     }
-    if let Err(e) = manipulator
-        .truncate_target_dir()
-        .with_context(|| "Failed to truncate target directory")
-    {
-        server
-            .disconnect(false)
-            .await
-            .with_context(|| "Failed to send final RCON messages")?;
-        bail!(e);
-    }
     Ok(())
 }
